
#ifndef MESSAGEVIEWER_EXPORT_H
#define MESSAGEVIEWER_EXPORT_H

#ifdef MESSAGEVIEWER_STATIC_DEFINE
#  define MESSAGEVIEWER_EXPORT
#  define MESSAGEVIEWER_NO_EXPORT
#else
#  ifndef MESSAGEVIEWER_EXPORT
#    ifdef KPim6MessageViewer_EXPORTS
        /* We are building this library */
#      define MESSAGEVIEWER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define MESSAGEVIEWER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef MESSAGEVIEWER_NO_EXPORT
#    define MESSAGEVIEWER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef MESSAGEVIEWER_DECL_DEPRECATED
#  define MESSAGEVIEWER_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef MESSAGEVIEWER_DECL_DEPRECATED_EXPORT
#  define MESSAGEVIEWER_DECL_DEPRECATED_EXPORT MESSAGEVIEWER_EXPORT MESSAGEVIEWER_DECL_DEPRECATED
#endif

#ifndef MESSAGEVIEWER_DECL_DEPRECATED_NO_EXPORT
#  define MESSAGEVIEWER_DECL_DEPRECATED_NO_EXPORT MESSAGEVIEWER_NO_EXPORT MESSAGEVIEWER_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef MESSAGEVIEWER_NO_DEPRECATED
#    define MESSAGEVIEWER_NO_DEPRECATED
#  endif
#endif
#include <messageviewer_version.h>

#define MESSAGEVIEWER_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(MESSAGEVIEWER_NO_DEPRECATED)
#  undef MESSAGEVIEWER_DEPRECATED
#  define MESSAGEVIEWER_DEPRECATED_EXPORT MESSAGEVIEWER_EXPORT
#  define MESSAGEVIEWER_DEPRECATED_NO_EXPORT MESSAGEVIEWER_NO_EXPORT
#elif defined(MESSAGEVIEWER_NO_DEPRECATED_WARNINGS)
#  define MESSAGEVIEWER_DEPRECATED
#  define MESSAGEVIEWER_DEPRECATED_EXPORT MESSAGEVIEWER_EXPORT
#  define MESSAGEVIEWER_DEPRECATED_NO_EXPORT MESSAGEVIEWER_NO_EXPORT
#else
#  define MESSAGEVIEWER_DEPRECATED MESSAGEVIEWER_DECL_DEPRECATED
#  define MESSAGEVIEWER_DEPRECATED_EXPORT MESSAGEVIEWER_DECL_DEPRECATED_EXPORT
#  define MESSAGEVIEWER_DEPRECATED_NO_EXPORT MESSAGEVIEWER_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define MESSAGEVIEWER_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define MESSAGEVIEWER_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef MESSAGEVIEWER_NO_DEPRECATED
#  define MESSAGEVIEWER_DISABLE_DEPRECATED_BEFORE_AND_AT MESSAGEVIEWER_VERSION
#endif
#ifdef MESSAGEVIEWER_NO_DEPRECATED_WARNINGS
#  define MESSAGEVIEWER_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef MESSAGEVIEWER_DEPRECATED_WARNINGS_SINCE
#  ifdef MESSAGEVIEWER_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define MESSAGEVIEWER_DEPRECATED_WARNINGS_SINCE MESSAGEVIEWER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define MESSAGEVIEWER_DEPRECATED_WARNINGS_SINCE MESSAGEVIEWER_VERSION
#  endif
#endif

#ifndef MESSAGEVIEWER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define MESSAGEVIEWER_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef MESSAGEVIEWER_DEPRECATED
#  define MESSAGEVIEWER_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > MESSAGEVIEWER_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define MESSAGEVIEWER_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* MESSAGEVIEWER_EXPORT_H */
